==> jc-1.4.0.tar.gz: soot/coffi/Instruction__5fIf__5ficmpne.h <==
// class soot.coffi.Instruction_If_icmpne

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class b569d3cf8762c695 soot_coffi_Instruction
// @dep_class 8c2087fadc1a9607 soot_coffi_Instruction__5fIf__5ficmpne
// @dep_class f1ed2760eb94209e soot_coffi_Instruction__5fbranch
// @dep_class 6bcdce6545109d8e soot_coffi_Instruction__5fintbranch

// header file dependencies
// @dep_header soot_coffi_Instruction__5fintbranch

#include "soot/coffi/Instruction__5fintbranch.h"

#ifndef _JC_soot_coffi_Instruction__5fIf__5ficmpne_H_
#define _JC_soot_coffi_Instruction__5fIf__5ficmpne_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_soot_coffi_Instruction__5fIf__5ficmpne$sub_refs	_jc_soot_coffi_Instruction__5fIf__5ficmpne$sub_refs;
typedef struct _jc_soot_coffi_Instruction__5fIf__5ficmpne$sub_nonrefs	_jc_soot_coffi_Instruction__5fIf__5ficmpne$sub_nonrefs;
typedef struct _jc_soot_coffi_Instruction__5fIf__5ficmpne$refs	_jc_soot_coffi_Instruction__5fIf__5ficmpne$refs;
typedef struct _jc_soot_coffi_Instruction__5fIf__5ficmpne$nonrefs	_jc_soot_coffi_Instruction__5fIf__5ficmpne$nonrefs;
typedef struct _jc_soot_coffi_Instruction__5fIf__5ficmpne$object	_jc_soot_coffi_Instruction__5fIf__5ficmpne$object;

typedef const struct _jc_soot_coffi_Instruction__5fIf__5ficmpne$vmethods	_jc_soot_coffi_Instruction__5fIf__5ficmpne$vmethods;
typedef const struct _jc_soot_coffi_Instruction__5fIf__5ficmpne$vtable	_jc_soot_coffi_Instruction__5fIf__5ficmpne$vtable;
typedef const struct _jc_soot_coffi_Instruction__5fIf__5ficmpne$vtype	_jc_soot_coffi_Instruction__5fIf__5ficmpne$vtype;

// Constructors
extern void _jc_soot_coffi_Instruction__5fIf__5ficmpne$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_coffi_Instruction__5fIf__5ficmpne$object *);

// Virtual methods structure
struct _jc_soot_coffi_Instruction__5fIf__5ficmpne$vmethods {
};

// Vtable
struct _jc_soot_coffi_Instruction__5fIf__5ficmpne$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_coffi_Instruction$vmethods	soot_coffi_Instruction;
	_jc_soot_coffi_Instruction__5fbranch$vmethods	soot_coffi_Instruction__5fbranch;
	_jc_soot_coffi_Instruction__5fintbranch$vmethods	soot_coffi_Instruction__5fintbranch;
	_jc_soot_coffi_Instruction__5fIf__5ficmpne$vmethods	soot_coffi_Instruction__5fIf__5ficmpne;
};

// Vtype
struct _jc_soot_coffi_Instruction__5fIf__5ficmpne$vtype {
	_jc_type			type;
	_jc_soot_coffi_Instruction__5fIf__5ficmpne$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_coffi_Instruction__5fIf__5ficmpne$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_coffi_Instruction__5fIf__5ficmpne$refs {
    _jc_soot_coffi_Instruction__5fIf__5ficmpne$sub_refs	soot_coffi_Instruction__5fIf__5ficmpne;
    _jc_soot_coffi_Instruction__5fintbranch$sub_refs	soot_coffi_Instruction__5fintbranch;
    _jc_soot_coffi_Instruction__5fbranch$sub_refs	soot_coffi_Instruction__5fbranch;
    _jc_soot_coffi_Instruction$sub_refs	soot_coffi_Instruction;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_coffi_Instruction__5fIf__5ficmpne$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_coffi_Instruction__5fIf__5ficmpne$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_coffi_Instruction$sub_nonrefs	soot_coffi_Instruction;
    _jc_soot_coffi_Instruction__5fbranch$sub_nonrefs	soot_coffi_Instruction__5fbranch;
    _jc_soot_coffi_Instruction__5fintbranch$sub_nonrefs	soot_coffi_Instruction__5fintbranch;
    _jc_soot_coffi_Instruction__5fIf__5ficmpne$sub_nonrefs	soot_coffi_Instruction__5fIf__5ficmpne;
};

// Object instance structure
struct _jc_soot_coffi_Instruction__5fIf__5ficmpne$object {
	_jc_soot_coffi_Instruction__5fIf__5ficmpne$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_coffi_Instruction__5fIf__5ficmpne$vtype	*vtype;
	_jc_soot_coffi_Instruction__5fIf__5ficmpne$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_coffi_Instruction__5fIf__5ficmpne$vtype _jc_soot_coffi_Instruction__5fIf__5ficmpne$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_coffi_Instruction__5fIf__5ficmpne, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_coffi_Instruction__5fIf__5ficmpne$class_object;

#endif	/* _JC_soot_coffi_Instruction__5fIf__5ficmpne_H_ */

==> jc-1.4.6.tar.gz: soot/coffi/Instruction__5fIf__5ficmpne.h <==
// class soot.coffi.Instruction_If_icmpne

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class b569d3cf8762c695 soot_coffi_Instruction
// @dep_class 8c2087fadc1a9607 soot_coffi_Instruction__5fIf__5ficmpne
// @dep_class f1ed2760eb94209e soot_coffi_Instruction__5fbranch
// @dep_class 6bcdce6545109d8e soot_coffi_Instruction__5fintbranch

// header file dependencies
// @dep_header soot_coffi_Instruction__5fintbranch

#include "soot/coffi/Instruction__5fintbranch.h"

#ifndef _JC_soot_coffi_Instruction__5fIf__5ficmpne_H_
#define _JC_soot_coffi_Instruction__5fIf__5ficmpne_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_soot_coffi_Instruction__5fIf__5ficmpne$sub_refs	_jc_soot_coffi_Instruction__5fIf__5ficmpne$sub_refs;
typedef struct _jc_soot_coffi_Instruction__5fIf__5ficmpne$sub_nonrefs	_jc_soot_coffi_Instruction__5fIf__5ficmpne$sub_nonrefs;
typedef struct _jc_soot_coffi_Instruction__5fIf__5ficmpne$refs	_jc_soot_coffi_Instruction__5fIf__5ficmpne$refs;
typedef struct _jc_soot_coffi_Instruction__5fIf__5ficmpne$nonrefs	_jc_soot_coffi_Instruction__5fIf__5ficmpne$nonrefs;
typedef struct _jc_soot_coffi_Instruction__5fIf__5ficmpne$object	_jc_soot_coffi_Instruction__5fIf__5ficmpne$object;

typedef const struct _jc_soot_coffi_Instruction__5fIf__5ficmpne$vmethods	_jc_soot_coffi_Instruction__5fIf__5ficmpne$vmethods;
typedef const struct _jc_soot_coffi_Instruction__5fIf__5ficmpne$vtable	_jc_soot_coffi_Instruction__5fIf__5ficmpne$vtable;
typedef const struct _jc_soot_coffi_Instruction__5fIf__5ficmpne$vtype	_jc_soot_coffi_Instruction__5fIf__5ficmpne$vtype;

// Constructors
extern void _jc_soot_coffi_Instruction__5fIf__5ficmpne$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_coffi_Instruction__5fIf__5ficmpne$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_soot_coffi_Instruction__5fIf__5ficmpne$vmethods {
};

// Vtable
struct _jc_soot_coffi_Instruction__5fIf__5ficmpne$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_coffi_Instruction$vmethods	soot_coffi_Instruction;
	_jc_soot_coffi_Instruction__5fbranch$vmethods	soot_coffi_Instruction__5fbranch;
	_jc_soot_coffi_Instruction__5fintbranch$vmethods	soot_coffi_Instruction__5fintbranch;
	_jc_soot_coffi_Instruction__5fIf__5ficmpne$vmethods	soot_coffi_Instruction__5fIf__5ficmpne;
};

// Vtype
struct _jc_soot_coffi_Instruction__5fIf__5ficmpne$vtype {
	_jc_type			type;
	_jc_soot_coffi_Instruction__5fIf__5ficmpne$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_coffi_Instruction__5fIf__5ficmpne$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_coffi_Instruction__5fIf__5ficmpne$refs {
    _jc_soot_coffi_Instruction__5fIf__5ficmpne$sub_refs	soot_coffi_Instruction__5fIf__5ficmpne;
    _jc_soot_coffi_Instruction__5fintbranch$sub_refs	soot_coffi_Instruction__5fintbranch;
    _jc_soot_coffi_Instruction__5fbranch$sub_refs	soot_coffi_Instruction__5fbranch;
    _jc_soot_coffi_Instruction$sub_refs	soot_coffi_Instruction;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_coffi_Instruction__5fIf__5ficmpne$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_coffi_Instruction__5fIf__5ficmpne$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_coffi_Instruction$sub_nonrefs	soot_coffi_Instruction;
    _jc_soot_coffi_Instruction__5fbranch$sub_nonrefs	soot_coffi_Instruction__5fbranch;
    _jc_soot_coffi_Instruction__5fintbranch$sub_nonrefs	soot_coffi_Instruction__5fintbranch;
    _jc_soot_coffi_Instruction__5fIf__5ficmpne$sub_nonrefs	soot_coffi_Instruction__5fIf__5ficmpne;
};

// Object instance structure
struct _jc_soot_coffi_Instruction__5fIf__5ficmpne$object {
	_jc_soot_coffi_Instruction__5fIf__5ficmpne$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_coffi_Instruction__5fIf__5ficmpne$vtype	*vtype;
	_jc_soot_coffi_Instruction__5fIf__5ficmpne$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_coffi_Instruction__5fIf__5ficmpne$vtype _jc_soot_coffi_Instruction__5fIf__5ficmpne$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_coffi_Instruction__5fIf__5ficmpne, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_coffi_Instruction__5fIf__5ficmpne$class_object;

#endif	/* _JC_soot_coffi_Instruction__5fIf__5ficmpne_H_ */
